MessageError

Enum MessageError 

pub enum MessageError {
    BufferTooSmall,
    TooShort,
    InvalidMagic,
    UnsupportedVersion,
    InvalidMessageType,
    PayloadTooLarge,
}
Errors that can occur when encoding or decoding a Peat-Lite message.

Variants



BufferTooSmall

Output buffer is too small for the encoded message.



TooShort

Input buffer is shorter than the minimum header size.



InvalidMagic

Magic bytes do not match.



UnsupportedVersion

Protocol version is not supported.



InvalidMessageType

Message type byte is not recognised.



PayloadTooLarge

Payload exceeds MAX_PAYLOAD_SIZE.